@@ -1,8 +1,6 @@
 from library_dicom.dicom_processor.model.Series import Series
 from library_dicom.dicom_processor.model.reader.Instance import Instance
 import pydicom
-import os
-import cv2 as cv2
 import numpy as np 
 import sys 
 
