@@ -1,6 +1,4 @@
 import pydicom 
-import numpy as np
-import cv2 
 
 class ReferencedFrameOfReferenceSequence :
 
